#!/bin/sh

USAGE="Usage: $0 <port> [ipv4 | ipv6]"

if [ -z "$1" ]; then
	echo $USAGE 1>&2
	exit 1
fi

PORT="$1"
shift

IPV6="no"
if [ "$1" = "ipv6" ]; then
	IPV6="yes"
	shift
elif [ "$1" = "ipv4" ]; then
	IPV6="ipv4"
	shift
fi

if [ -n "$1" ] ; then
	echo "Unknown extra args: $@" 1>&2
	echo $USAGE 1>&2
	exit 1
fi

# Checking IPv6 into system status:
IPV6_SOCKET="no"

# TODO: adaptation for FreeBSD
if [ -f /proc/net/if_inet6 ] ; then
	IPV6_SOCKET="only"

	# is IPv6 socket accepts IPv4 connections?
	if [ "X`/sbin/sysctl -n net.ipv6.bindv6only`" = "X0" ] ; then
		IPV6_SOCKET="yes"
	elif [ -d "/proc/vz" ] ; then
		# Bind only v6 under Virtuozzo
		IPV6_SOCKET="yes"
	fi
fi

# IPv6 is not supported by OS settings.
if [ $IPV6 = "yes" -a $IPV6_SOCKET = "no" ] ; then
	exit 0
fi

# In that case IPv6 socket can server IPv4 clients,
# so IPv4 section not needed at all
if [ $IPV6 = "no" -a $IPV6_SOCKET = "yes" ] ; then
	exit 0
fi
# Otherwise, if ipv4 option was passed we generate 
# config only for ipv4. No call with ipv6 is expected then.

# Define how server socket matcher looks like
if [ $IPV6_SOCKET = "only" -a $IPV6 = "yes" ]; then
	SOCK_MATCHER="[::]:$PORT"
else
	SOCK_MATCHER=":$PORT"
fi

print_handler()
{
	local handler_type="$1"
	local socket_postfix=""
	if [ $PORT != "8443" ]; then
		socket_postfix="$socket_postfix.$PORT"
	fi
	if [ $IPV6 = "yes" -a $IPV6_SOCKET = "only" ]; then
		socket_postfix="$socket_postfix.ipv6"
	fi
	socket_postfix="$socket_postfix.socket"

	cat <<EOF
		"/" + var.sso_${handler_type}_script => ((
			  "socket"       => var.sso_tmpdir + var.sso_${handler_type}_script + "$socket_postfix",
			  "bin-path"     => var.sso_interpreter,
			  "bin-username" => var.sso_username,
			  "check-local"  => "disable",
			  "min-procs"    => 0,
			  "max-procs"    => 1,
			  "idle-timeout" => 100,
			  "broken-scriptfilename" => "enable",
			  "bin-environment" => (
				"SSO_RELAY_PORT" => "$PORT",
				"SSO_CONFIG_FILE" => var.sso_config,
				"TEMP" => var.sso_tmpdir,
				"PHP_FCGI_CHILDREN" => var.sso_fcgi_children,
				"PHP_FCGI_MAX_REQUESTS" => var.sso_fcgi_max_requests
			  )
			)),

EOF
}

cat <<EOF
# Both API and RELAY interfaces reside on a single port.
\$SERVER["socket"] == "$SOCK_MATCHER" {
	include_shell var.sso_ssl_conf_script

	# Prefix pattern matching of .php scripts requires that this 
	# configuration file is included before others.
	fastcgi.server += (
EOF
		print_handler main
		print_handler relay
cat <<EOF
	)

# Aliases for site/relay of sso
    alias.url += (
        "/sso-site" => var.sso_bindir ,
        "/sso-relay" => var.sso_bindir ,
    )

# SSO site rewrites
    url.rewrite-once += (
        "^/sp$" => "/sso-site/sso_main.php",
        "^/sp/(.*)" => "/sso-site/sso_main.php/\$1",
        "^/fi$" => "/sso-site/sso_main.php",
        "^/fi/(.*)" => "/sso-site/sso_main.php/\$1",
        "^/meta$" => "/sso-site/sso_main.php",
    )

# SSO relay
    url.rewrite-once += (
        "^/relay$" => "/sso-relay/sso_relay.php",
        "^/relay/(.*)" => "/sso-relay/sso_relay.php/\$1",
        "^/signout$" => "/sso-relay/sso_relay.php",
        "^/signout/(.*)" => "/sso-relay/sso_relay.php/\$1",
        "^/SAML$" => "/sso-relay/sso_relay.php",
        "^/SAML/(.*)" => "/sso-relay/sso_relay.php/\$1",
    )
# fi_ui doesn't used at all, so  no rewrite for it
}
EOF
