#!/bin/sh
#
# Produces SSL configuration options for sw-cp-server SSO configuration.
# Ensures that no collision occures with similar options used by Plesk.
#

if [ "`id -u`" -ne 0 ]; then
	exit 0
fi

CERT_FILE="/etc/sso/sso.pem"
PSA_CONF="/etc/sw-cp-server/applications.d/plesk.conf"
PSA_SSL_CONF="/usr/local/psa/admin/conf/ssl-conf.sh"
SSO_PCI_INC="/etc/sw-cp-server/applications.d/sso.pci.inc"

if [ -f "$PSA_CONF" -a -x "$PSA_SSL_CONF" ]; then
	conf=`$PSA_SSL_CONF`
fi

if ! (echo "$conf" | grep -q '^ssl\.engine'); then
	echo 'ssl.engine = "enable"'
fi

if ! (echo "$conf" | grep -q '^ssl\.pemfile'); then
	echo "ssl.pemfile = \"$CERT_FILE\""
fi

echo 'ssl.req-client-cert = "enable"'

# Fetch SSO PCI compliance options if they are defined
if [ -f "$SSO_PCI_INC" ]; then
	cat "$SSO_PCI_INC"
fi
